**FastQ to FASTA file converter**

# Installation

```r{}
pip install FastqToFastaConverter
```
# Running

```r{}
from FastqToFastaConverter.fastq2fasta import FastqToFastaConverter
converter = FastqToFastaConverter()
converter.convert('input.fastq')

```
